<?php
/**
 * @file
 * accounts.rules_defaults.inc
 */

/**
 * Implements hook_default_rules_configuration().
 */
function accounts_default_rules_configuration() {
  $items = array();
  $items['rules_after_saving_a_new_account'] = entity_import('rules_config', '{ "rules_after_saving_a_new_account" : {
      "LABEL" : "After saving a new account",
      "PLUGIN" : "reaction rule",
      "OWNER" : "rules",
      "TAGS" : [ "Account" ],
      "REQUIRES" : [ "rules" ],
      "ON" : { "node_insert" : [] },
      "IF" : [
        { "entity_is_of_bundle" : {
            "entity" : [ "node" ],
            "type" : "node",
            "bundle" : { "value" : { "account" : "account" } }
          }
        }
      ],
      "DO" : [
        { "component_rules_assign_trail_for_account" : { "account_node" : [ "node" ] } }
      ]
    }
  }');
  $items['rules_after_updating_existing_content_of_type_account'] = entity_import('rules_config', '{ "rules_after_updating_existing_content_of_type_account" : {
      "LABEL" : "After updating existing content of type account",
      "PLUGIN" : "reaction rule",
      "OWNER" : "rules",
      "TAGS" : [ "Account" ],
      "REQUIRES" : [ "rules" ],
      "ON" : { "node_update" : [] },
      "IF" : [
        { "entity_is_of_bundle" : {
            "entity" : [ "node" ],
            "type" : "node",
            "bundle" : { "value" : { "account" : "account" } }
          }
        }
      ],
      "DO" : [
        { "component_rules_assign_trail_for_account" : { "account_node" : [ "node" ] } }
      ]
    }
  }');
  $items['rules_assign_trail_for_account'] = entity_import('rules_config', '{ "rules_assign_trail_for_account" : {
      "LABEL" : "Assign trail for Account",
      "PLUGIN" : "rule",
      "OWNER" : "rules",
      "TAGS" : [ "Account" ],
      "REQUIRES" : [ "rules" ],
      "USES VARIABLES" : { "account_node" : { "label" : "Account node", "type" : "node" } },
      "IF" : [
        { "entity_is_of_bundle" : {
            "entity" : [ "account-node" ],
            "type" : "node",
            "bundle" : { "value" : { "account" : "account" } }
          }
        },
        { "NOT data_is_empty" : { "data" : [ "account-node:field-reporting-hierarchy" ] } },
        { "entity_is_of_bundle" : {
            "entity" : [ "account-node:field-reporting-hierarchy" ],
            "type" : "taxonomy_term",
            "bundle" : { "value" : { "reporting_hierarchy" : "reporting_hierarchy" } }
          }
        }
      ],
      "DO" : [
        { "data_set" : {
            "data" : [ "account-node:field-trail" ],
            "value" : [ "account-node:field-reporting-hierarchy:parents-all" ]
          }
        }
      ]
    }
  }');
  $items['rules_clone_account'] = entity_import('rules_config', '{ "rules_clone_account" : {
      "LABEL" : "Clone account",
      "PLUGIN" : "rule",
      "OWNER" : "rules",
      "TAGS" : [ "Account" ],
      "REQUIRES" : [ "rules" ],
      "USES VARIABLES" : { "account_node" : { "label" : "Account node", "type" : "node" } },
      "IF" : [
        { "entity_is_of_bundle" : {
            "entity" : [ "account-node" ],
            "type" : "node",
            "bundle" : { "value" : { "account" : "account" } }
          }
        }
      ],
      "DO" : [
        { "entity_create" : {
            "USING" : {
              "type" : "node",
              "param_type" : "account",
              "param_title" : "Temp account title",
              "param_author" : [ "site:current-user" ]
            },
            "PROVIDE" : { "entity_created" : { "entity_created" : "Created entity" } }
          }
        },
        { "entity_save" : { "data" : [ "entity-created" ], "immediate" : "1" } },
        { "data_set" : {
            "data" : [ "entity-created:title" ],
            "value" : "[account-node:title] [CLONED]"
          }
        },
        { "data_set" : {
            "data" : [ "entity-created:field-reporting-hierarchy" ],
            "value" : [ "account-node:field-reporting-hierarchy" ]
          }
        },
        { "entity_save" : { "data" : [ "entity-created" ], "immediate" : "1" } },
        { "redirect" : {
            "url" : "node\\/[entity-created:nid]\\/edit?destination=[site:current-page:path]",
            "destination" : "1"
          }
        }
      ]
    }
  }');
  $items['rules_link_condition_clone_account_button'] = entity_import('rules_config', '{ "rules_link_condition_clone_account_button" : {
      "LABEL" : "Rules link: Clone account button condition",
      "PLUGIN" : "and",
      "OWNER" : "rules",
      "USES VARIABLES" : { "node" : { "type" : "node", "label" : "node" } },
      "AND" : []
    }
  }');
  $items['rules_link_set_clone_account_button'] = entity_import('rules_config', '{ "rules_link_set_clone_account_button" : {
      "LABEL" : "Rules link: Clone account button rules set",
      "PLUGIN" : "rule set",
      "OWNER" : "rules",
      "REQUIRES" : [ "rules" ],
      "USES VARIABLES" : { "node" : { "type" : "node", "label" : "node" } },
      "RULES" : [
        { "RULE" : {
            "IF" : [
              { "entity_is_of_bundle" : {
                  "entity" : [ "node" ],
                  "type" : "node",
                  "bundle" : { "value" : { "account" : "account" } }
                }
              }
            ],
            "DO" : [ { "component_rules_clone_account" : { "account_node" : [ "node" ] } } ],
            "LABEL" : "Clone account button rule"
          }
        }
      ]
    }
  }');
  return $items;
}
